@@ -34,6 +34,8 @@ from nise.util import LOG_VERBOSITY
 from nise.yaml_gen import add_yaml_parser_args
 from nise.yaml_gen import yaml_main
 
+os.environ["TZ"] = "UTC"
+
 
 class NiseError(Exception):
     """A Nise Exception class."""
@@ -121,6 +123,14 @@ def add_azure_parser_args(parser):
         default=os.getenv("AZURE_STORAGE_ACCOUNT"),
         help="Azure container to place the data.",
     )
+    parser.add_argument(
+        "-v2",
+        "--version-two",
+        dest="version_two",
+        action="store_true",
+        required=False,
+        help="Generate version two of the azure report.",
+    )
 
 
 def add_gcp_parser_args(parser):
@@ -451,8 +461,6 @@ def _load_static_report_data(options):
                 generated_end_date = today()
             if options.get("provider") == "azure":
                 generated_end_date += datetime.timedelta(hours=24)
-            else:
-                generated_end_date = generated_end_date.replace(hour=23, minute=59)
             end_dates.append(generated_end_date)
 
             attributes["start_date"] = str(generated_start_date)
